@@ -154,8 +154,8 @@ def make_link_list(ctx, stmt, link_list):
 
 def emit_stmt(ctx, stmt, fd, level, prev_kwd, prev_kwd_class, islast,
               indent, indentstep, link_list):
-    # line end comment has been printed
     if is_line_end_comment(stmt):
+        # line end comments has been printed after last meaningful statement
         return
 
     if ctx.opts.yang_remove_unused_imports and stmt.keyword == 'import':
@@ -243,7 +243,7 @@ def emit_stmt(ctx, stmt, fd, level, prev_kwd, prev_kwd_class, islast,
     fd.write(eol)
 
     next_stmt = link_list.get(stmt, None)
-    emit_line_end_comments_after(stmt, next_stmt, link_list, fd, False)
+    emit_line_end_comments(stmt, next_stmt, link_list, fd, False)
     fd.write('\n')
 
     if len(stmt.substmts) > 0:
@@ -278,7 +278,7 @@ def emit_stmt(ctx, stmt, fd, level, prev_kwd, prev_kwd_class, islast,
         last_substmt = link_list['last']
         if last_substmt in link_list:
             last_substmt = link_list[last_substmt]
-        emit_line_end_comments_after(stmt, last_substmt, link_list, fd, True)
+        emit_line_end_comments(stmt, last_substmt, link_list, fd, True)
         fd.write('\n')
 
     if (not islast and
@@ -287,16 +287,22 @@ def emit_stmt(ctx, stmt, fd, level, prev_kwd, prev_kwd_class, islast,
          stmt.keyword in _keyword_with_trailing_blank_line)):
         fd.write('\n')
 
-def emit_line_end_comments_after(stmt, last_substmt, link_list, fd, need_same_level):
-    while last_substmt is not None:
+def emit_line_end_comments(stmt, next_stmt, link_list, fd, same_level):
+    """
+    emit line end comment stmts, there are some cases:
+    1. after "{"
+    2. after "}"
+    3. multi line end comments should be printed in oneline
+    """
+    while next_stmt is not None:
         is_sub_level = False
-        if not need_same_level:
-            is_sub_level = last_substmt.parent == stmt
-        if (is_line_end_comment(last_substmt) and
-                (last_substmt.parent == stmt.parent or (not need_same_level and is_sub_level))):
-            fd.write(' ' + last_substmt.arg)
-            if last_substmt in link_list:
-                last_substmt = link_list[last_substmt]
+        if not same_level:
+            is_sub_level = next_stmt.stmt_parent == stmt
+        if (is_line_end_comment(next_stmt) and
+                (next_stmt.stmt_parent == stmt.stmt_parent or (not same_level and is_sub_level))):
+            fd.write(' ' + next_stmt.arg)
+            if next_stmt in link_list:
+                next_stmt = link_list[next_stmt]
             else:
                 return
         else:
